#include "vbc.h"
#include <glib/gstdio.h>

static GtkWidget *gvim_window;
static GtkWidget *instructions_window;

static void response_cb(GtkDialog *dialog, gint response, gpointer data)
{
  GtkWidget **win = (GtkWidget **) data;

  *win = NULL;
  gtk_widget_destroy (GTK_WIDGET (dialog));
}

static void show_instructions(GtkWidget *parent, const gchar *title, const gchar *man, GtkWidget **win)
{
   GtkWidget *window, *view;
   GtkWidget *frame;
   GtkTextBuffer *buffer;
   GtkTextIter iter;
   FILE *infile;
   gchar file_buff[MAXCHAT];
   gchar *filename;
   gint nchars;

   if (*win) {
     gtk_window_present (GTK_WINDOW (*win));
     return;
   }

   window = gtk_dialog_new_with_buttons (title, GTK_WINDOW(parent),
      GTK_DIALOG_DESTROY_WITH_PARENT,
      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
   gtk_window_set_default_size (GTK_WINDOW (window), 550, 525);

   /* this tells the window manager the smallest size
    * good idea to set this, else the UI can start to look goofy 
    */
   gtk_widget_set_size_request (window, 200, 200);
   gtk_container_set_border_width (GTK_CONTAINER (window), 8);

   /* I add a frame around the vbox to make things look better */
   frame = gtk_frame_new ("Let the Computer Be Your Voice");
   gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(GTK_DIALOG(window))), frame);

   /* at this point we have:
    * window with a frame inside it ( a frame is a container )
    */
   view = gtk_text_view_new ();
   gtk_text_view_set_editable(GTK_TEXT_VIEW(view), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (view), 6);
   gtk_container_add (GTK_CONTAINER (frame), view);

   /* fetch the buffer from the text view and get offset 0 */
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
   gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);

   /* pull in data from gvim file and insert starting at iter */
   filename = g_build_filename (vhome, man, NULL);
   infile = g_fopen (filename, "r");
   if (infile)
     {
	while (1)
	  {
	     nchars = fread (file_buff, 1, MAXCHAT, infile);
	     gtk_text_buffer_insert (buffer, &iter, file_buff, nchars);
	     if (nchars < MAXCHAT)
		break;
	  }
	fclose (infile);
     }
   else
      g_print ("\nERROR! could not open file %s\n", filename);
   g_free (filename);

   *win = window;
   g_signal_connect (window, "response", G_CALLBACK (response_cb),
		     win);

   gtk_widget_show_all (window);
}

/*
 *  the following callback reads in ~/.VBC/.Gvim.txt that tells how to use gvim.
 */
void
show_gvim_cb (GtkAction *action, GtkWidget *parent)
{
  show_instructions(parent, "Gvim Instructions", GVIM, &gvim_window);
}

/*
 *  the following callback reads in ~/.VBC/.Instructions.txt that tells how to
 *  use VBC.  [[ May need/WANT to divide to explain "Display Textfile" (?)
 */
void
show_instructions_cb (GtkAction *action, GtkWidget *parent)
{
  show_instructions(parent, "Instructions", INSTRUCT, &instructions_window);
}

